import web
import config
import json


class Api_products:
    def get(self, id_product):
        try:
            # http://api_products?user_hash=12345&action=get
            if id_product == None:
                result = config.model.get_all_products()
                products_json = []
                for row in result:
                    tmp = str(dict(row))
                    products_json.append(tmp)
                web.header('Content-Type', 'application/json')
                return json.dumps(products_json)
            else:
                # http://api_products?user_hash=12345&action=get&id_product=1
                result = config.model.get_products(int(id_product))
                products_json = []
                products_json.append(str(dict(result)))
                web.header('Content-Type', 'application/json')
                return json.dumps(products_json)
        except Exception as e:
            print "GET Error {}".format(e.args)
            products_json = '[]'
            web.header('Content-Type', 'application/json')
            return json.dumps(products_json)

# https://0.0.0.0:8080/api_products?user_hash=12345&action=put&id_product=1&product=nuevo&description=nueva&stock=10&purchase_price=1&price_sale=3&product_image=0
    def put(self, product, description, stock, purchase_price, price_sale, product_image):
        try:
            config.model.insert_products(
                product, description, stock, purchase_price, price_sale, product_image)
            products_json = '[{200}]'
            web.header('Content-Type', 'application/json')
            return json.dumps(products_json)
        except Exception as e:
            print "PUT Error {}".format(e.args)
            return None
# http://api_products?user_hash=12345&action=get&id_product=1
    def delete(self, id_product):
        try:
            config.model.delete_products(id_product)
            products_json = '[{200}]'
            web.header('Content-Type', 'application/json')
            return json.dumps(products_json)
        except Exception as e:
            print "DELETE Error {}".format(e.args)
            return None
# https://0.0.0.0:8080/api_products?user_hash=12345&action=update&id_product=1&product=nuevo&description=nueva&stock=10&purchase_price=1&price_sale=3&product_image=default.jpg
    def update(self, id_product, product, description, stock, purchase_price, price_sale, product_image):
        try:
            config.model.edit_products(id_product,product, description, stock, purchase_price, price_sale, product_image)
            products_json = '[{200}]'
            web.header('Content-Type', 'application/json')
            return json.dumps(products_json)
        except Exception as e:
            print "GET Error {}".format(e.args)
            products_json = '[]'
            web.header('Content-Type', 'application/json')
            return json.dumps(products_json)

    def GET(self):
        user_data = web.input(
            user_hash=None,
            action=None,
            id_product=None,
            product=None,
            description=None,
            stock=None,
            purchase_price=None,
            price_sale=None,
            product_image=None
        )
        try:
            user_hash = user_data.user_hash  # user validation
            action = user_data.action  # action GET, PUT, DELETE, UPDATE
            id_product = user_data.id_product
            product = user_data.product
            description = user_data.description
            stock = user_data.stock
            purchase_price = user_data.purchase_price
            price_sale = user_data.price_sale
            product_image = user_data.product_image

            if user_hash == '12345':  # user_hash
                if action == None:
                    raise web.seeother('/404')
                elif action == 'get':
                    return self.get(id_product)
                elif action == 'put':
                    return self.put(product, description, stock, purchase_price, price_sale, product_image)
                elif action == 'delete':
                    return self.delete(id_product)
                elif action == 'update':
                    return self.update(id_product, product, description, stock, purchase_price, price_sale, product_image)
            else:
                raise web.seeother('/404')
        except Exception as e:
            print "WEBSERVICE Error {}".format(e.args)
            raise web.seeother('/404')



import web
import config

db = config.db

def get_all_table_name():
    try:
        return db.select('table_name')
    except Exception as e:
        print "Model get all Error {}".format(e.args)
        print "Model get all Message {}".format(e.message)
        return None

def get_table_name(primary_key):
    try:
        return db.select('table_name', where='primary_key=$primary_key', vars=locals())[0]
    except Exception as e:
        print "Model get Error {}".format(e.args)
        print "Model get Message {}".format(e.message)
        return None

def delete_table_name(primary_key):
    try:
        return db.delete('table_name', where='primary_key=$primary_key', vars=locals())
    except Exception as e:
        print "Model delete Error {}".format(e.args)
        print "Model delete Message {}".format(e.message)
        return None

def insert_table_name(fields):
    try:
        db.insert('table_name',values)
    except Exception as e:
        print "Model insert Error {}".format(e.args)
        print "Model insert Message {}".format(e.message)
        return None

def edit_table_name(field_all):
    try:
        db.update('table_name',value_all,
                  where='primary_key=$primary_key',
                  vars=locals())
    except Exception as e:
        print "Model update Error {}".format(e.args)
        print "Model updateMessage {}".format(e.message)
        return None



import config
import app

class Guess:

    def GET(self):  
        if app.session.loggedin == True:
            username = app.session.username
            privilege = app.session.privilege
            return config.render.guess(username)
        else:
            raise config.web.seeother('/login')



#Author : Salvador Hernandez Mendoza
#Email  : salvadorhm@gmail.com
#Twitter: @salvadorhm
import web
import application

ssl = False #activate ssl certificate 

if ssl == True:
    from web.wsgiserver import CherryPyWSGIServer
    CherryPyWSGIServer.ssl_certificate = "ssl/server.crt" 
    CherryPyWSGIServer.ssl_private_key = "ssl/server.key"

urls = (
    '/', 'application.controllers.persons.index.Index',
    '/insert', 'application.controllers.persons.insert.Insert',
    '/update/(.+)', 'application.controllers.persons.update.Update',
    '/view/(.+)', 'application.controllers.persons.view.View',
    '/delete/(.+)', 'application.controllers.persons.delete.Delete',
    '/api_persons/?', 'application.api.persons.api_persons.Api_persons'
)

if __name__ == "__main__":
    app = web.application(urls, globals())
    web.config.debug = False
    app.run()



import config


class Delete:

	def GET(self, id_product):
		result = config.model.get_products(int(id_product))
		return config.render.delete(result)

	def POST(self, id_product):
		form = config.web.input()
		config.model.delete_products(form['id_product'])
		raise config.web.seeother('/')



import web
import config

db = config.db

def validate_user(username, password):
    try:
        return db.select('users',where='username=$username and password=$password', vars=locals())[0]
    except Exception as e:
        print "Model get all Error {}".format(e.args)
        print "Model get all Message {}".format(e.message)
        return None


import web
import config
import json

class Api_table_name:
	def get(self, primary_key):
		try:
			# http://api_table_name?user_hash=12345&action=get
			if primary_key == None:
				result = config.model.get_all_table_name()
				table_name_json = []
				for row in result:
					tmp = dict(row)
					table_name_json.append(tmp)
				web.header('Content-Type', 'application/json')
				return json.dumps(table_name_json)
			else:
				# http://api_table_name?user_hash=12345&action=get&primary_key=1
				result = config.model.get_table_name(int(primary_key))
				table_name_json = []
				table_name_json.append(dict(result))
				web.header('Content-Type', 'application/json')
				return json.dumps(table_name_json)
		except Exception as e:
			print "GET Error {}".format(e.args)
			table_name_json = '[]'
			web.header('Content-Type', 'application/json')
			return json.dumps(table_name_json)

# https://0.0.0.0:8080/api_table_name?user_hash=12345&action=put&primary_key=1&product=nuevo&description=nueva&stock=10&purchase_price=1&price_sale=3&product_image=0
	def put(self, fields):
		try:
			config.model.insert_table_name(fields)
			table_name_json = '[{200}]'
			web.header('Content-Type', 'application/json')
			return json.dumps(table_name_json)
		except Exception as e:
			print "PUT Error {}".format(e.args)
			return None

# http://api_table_name?user_hash=12345&action=get&primary_key=1
	def delete(self, primary_key):
		try:
			config.model.delete_table_name(primary_key)
			table_name_json = '[{200}]'
			web.header('Content-Type', 'application/json')
			return json.dumps(table_name_json)
		except Exception as e:
			print "DELETE Error {}".format(e.args)
			return None

# https://0.0.0.0:8080/api_table_name?user_hash=12345&action=update&primary_key=1&product=nuevo&description=nueva&stock=10&purchase_price=1&price_sale=3&product_image=default.jpg
	def update(self, primary_key, fields):
		try:
			config.model.edit_table_name(field_all)
			table_name_json = '[{200}]'
			web.header('Content-Type', 'application/json')
			return json.dumps(table_name_json)
		except Exception as e:
			print "GET Error {}".format(e.args)
			table_name_json = '[]'
			web.header('Content-Type', 'application/json')
			return json.dumps(table_name_json)

	def GET(self):
		user_data = web.input(
			user_hash=None,
			action=None,
field_none
		)
		try:
			user_hash = user_data.user_hash  # user validation
			action = user_data.action  # action GET, PUT, DELETE, UPDATE
field_user_data

			if user_hash == '12345':  # user_hash
				if action == None:
					raise web.seeother('/404')
				elif action == 'get':
					return self.get(primary_key)
				elif action == 'put':
					return self.put(fields)
				elif action == 'delete':
					return self.delete(primary_key)
				elif action == 'update':
					return self.update(primary_key, fields)
			else:
				raise web.seeother('/404')
		except Exception as e:
			print "WEBSERVICE Error {}".format(e.args)
			raise web.seeother('/404')



import web
import os

class Api_generator:
    
    db_host = 'localhost'
    db_name = 'acme_store'
    db_user = 'root'
    db_pw = 'toor'

    table_name = ''

    db = web.database(
            dbn='mysql',
            host=db_host,
            db=db_name,
            user=db_user,
            pw=db_pw
            )

    def conectar(self):
        try:
            new_db = web.database(
            dbn='mysql',
            host=self.db_host,
            db=self.db_name,
            user=self.db_user,
            pw=self.db_pw
            )
            self.db = new_db
            print 'Conectado'
        except Exception as e:
            print e.args
            print "Error en conexion {}".format(e.message)

    def get_tables(self):
        try:
            return self.db.query('show tables')
        except Exception as e:
            print e.args
            print "Error en get_tables {}".format(e.message)
            return None

    def describre_tables(self,table):
        try:
            sql = 'describe {}'.format(table)
            return self.db.query(sql, vars=locals())
        except Exception as e:
            print e.args
            print "Error  describe_tables {}".format(e.message)
            return None

    def get_fields(self,table):
        try:
            result = self.describre_tables(table)
            fields = []
            for i in result:
                r = [i.Field, i.Key]
                fields.append(r)
            return fields
        except Exception as e:
            print e.args
            print "Error get_fields {}".format(e.message)
            return None

    def get_primary_key(self,fields):
        primary_key = ''
        for field in fields:
            try:
                if field[1] == 'PRI':
                    primary_key = field[0]
                    exit
            except:
                primary_key = None
        return primary_key

    def super_cool(self,table_name):
        try:
            primary_key = self.get_primary_key(self.get_fields(table_name))

            script_path = os.path.abspath(__file__)
            script_dir = os.path.split(script_path)[0]
            rel_path = "plugin"
            abs_file_path = os.path.join(script_dir, rel_path)
            
            file = open(abs_file_path+'/api_master_cool.py','r')
            plantilla = ''
            for line in file:
                plantilla += line
            
            field_all = ""
            for field in self.get_fields(table_name):
                field_all += field[0] + ','
            field_all = field_all[:-1]

            field_none = ""
            for field in self.get_fields(table_name):
                field_none += '\t\t\t'+field[0] + '=None,\n'
            field_none = field_none[:-1]

            field_user_data = ""
            for field in self.get_fields(table_name):
                field_user_data += '\t\t\t'+field[0] + '=user_data.' + field[0] +'\r'
                field_user_data += '\n'
            field_user_data = field_user_data[:-1]
        
            fields = ""
            for field in self.get_fields(table_name)[1:]:
                fields += field[0] + ','
            fields = fields[:-1]

            plantilla = plantilla.replace('table_name', table_name)
            plantilla = plantilla.replace('primary_key', primary_key)
            plantilla = plantilla.replace('fields', fields)
            plantilla = plantilla.replace('field_all', field_all)
            plantilla = plantilla.replace('field_none', field_none)
            plantilla = plantilla.replace('field_user_data', field_user_data)


            api = plantilla
            self.new_folder(table_name)
            file = open(table_name+'/api_' + table_name + '.py', 'w')
            file.write(api)
            file.close()

            config ='''import web
import application.models.model_table_name
model = application.models.model_table_name
'''
            config = config.replace('table_name', table_name)

            file_config = open(table_name+'/config.py', 'w')
            file_config.write(config)
            file.close()

            file_init = open(table_name+'/__init__.py', 'w')
            file_init.write('')
            file_init.close()

        except Exception as e:
            print e.args
            print e.message
            print "Error en supercool {}".format(e.message)

    def new_folder(self, table_name):
    	try:
            os.makedirs(table_name)
        except Exception as e:
            print "ERROR create dir {}".format(e.message)

    def generate(self):
        try:
            for i in self.get_tables():
                m = str(i.values())
                self.super_cool(m[3:-2])
        except Exception as e:
            print "Error en generate {}".format(e.message)

    def generate_one(self, table_name):
        try:
            self.super_cool(table_name)
        except Exception as e:
            print "Error al generar {}".format(e.message)



import web
from web import form
import application.models.model_persons

render = web.template.render('application/views/persons/', base='master')
model = application.models.model_persons

vemail = form.regexp(r".*@.*", "Must be a valid email address")
'''
Here we define the form fields for use in all the views
'''
form_persons = form.Form(
            form.Hidden('id_person',description="", value="0", class_="form-control", required=True),
            form.Textbox('name',description="name", class_="form-control", required=True),
            form.Textbox('telephone',description="telephone", class_="form-control", required=True),
            form.Textbox('email', vemail, description="Email", class_="form-control", required=True),
        )
        


import web
import config

db = config.db


def get_all_products():
    try:
        return db.select('products')
    except Exception as e:
        print "Model get all Error {}".format(e.args)
        print "Model get all Message {}".format(e.message)
        return None

def get_products(id_product):
    try:
        return db.select('products', where='id_product=$id_product', vars=locals())[0]
    except Exception as e:
        print "Model get Error {}".format(e.args)
        print "Model get aMessage {}".format(e.message)
        return None

def delete_products(id_product):
    try:
        return db.delete('products', where='id_product=$id_product', vars=locals())
    except Exception as e:
        print "Model delete Error {}".format(e.args)
        print "Model delete Message {}".format(e.message)
        return None

def insert_products(product, description, stock, purchase_price, price_sale, product_image):
    try:
        db.insert('products',
                  product=product,
                  description=description,
                  stock=stock,
                  purchase_price=purchase_price,
                  price_sale=price_sale,
                  product_image=product_image)
    except Exception as e:
        print "Model insert Error {}".format(e.args)
        print "Model insert Message {}".format(e.message)
        return None

def edit_products(id_product, product, description, stock, purchase_price, price_sale, product_image):
    try:
        db.update('products',
                  product=product,
                  description=description,
                  stock=stock,
                  purchase_price=purchase_price,
                  price_sale=price_sale,
                  product_image=product_image,
                  where='id_product=$id_product',
                  vars=locals())
    except Exception as e:
        print "Model update Error {}".format(e.args)
        print "Model update Message {}".format(e.message)
        return None



import web
import config
import json

class Api_persons:
	def get(self, id_person):
		try:
			# http://0.0.0.0:8080/api_persons?user_hash=12345&action=get
			if id_person == None:
				result = config.model.get_all_persons()
				persons_json = []
				for row in result:
					tmp = dict(row)
					persons_json.append(tmp)
				web.header('Content-Type', 'application/json')
				return json.dumps(persons_json)
			else:
				# http://0.0.0.0:8080/api_persons?user_hash=12345&action=get&id_person=1
				result = config.model.get_persons(int(id_person))
				persons_json = []
				persons_json.append(dict(result))
				web.header('Content-Type', 'application/json')
				return json.dumps(persons_json)
		except Exception as e:
			print "GET Error {}".format(e.args)
			persons_json = '[]'
			web.header('Content-Type', 'application/json')
			return json.dumps(persons_json)

# https://0.0.0.0:8080/api_persons?user_hash=12345&action=put&id_person=1&name=new&telephone=12345&email=new@email.com
	def put(self, name,telephone,email):
		try:
			config.model.insert_persons(name,telephone,email)
			persons_json = '[{200}]'
			web.header('Content-Type', 'application/json')
			return json.dumps(persons_json)
		except Exception as e:
			print "PUT Error {}".format(e.args)
			return None

# http://0.0.0.0:8080/api_persons?user_hash=12345&action=get&id_person=1
	def delete(self, id_person):
		try:
			config.model.delete_persons(id_person)
			persons_json = '[{200}]'
			web.header('Content-Type', 'application/json')
			return json.dumps(persons_json)
		except Exception as e:
			print "DELETE Error {}".format(e.args)
			return None

# https://0.0.0.0:8080/api_persons?user_hash=12345&action=update&id_person=1&name=new&telephone=12345&email=new@email.com
	def update(self, id_person, name,telephone,email):
		try:
			config.model.update_persons(id_person,name,telephone,email)
			persons_json = '[{200}]'
			web.header('Content-Type', 'application/json')
			return json.dumps(persons_json)
		except Exception as e:
			print "GET Error {}".format(e.args)
			persons_json = '[]'
			web.header('Content-Type', 'application/json')
			return json.dumps(persons_json)

	def GET(self):
		user_data = web.input(
			user_hash=None,
			action=None,
			id_person=None,
			name=None,
			telephone=None,
			email=None,
		)
		try:
			user_hash = user_data.user_hash  # user validation
			action = user_data.action  # action GET, PUT, DELETE, UPDATE
			id_person=user_data.id_person
			name=user_data.name
			telephone=user_data.telephone
			email=user_data.email
			
			#change de user_hash 
			if user_hash == '12345':  # user_hash
				if action == None:
					raise web.seeother('/404')
				elif action == 'get':
					return self.get(id_person)
				elif action == 'put':
					return self.put(name,telephone,email)
				elif action == 'delete':
					return self.delete(id_person)
				elif action == 'update':
					return self.update(id_person, name,telephone,email)
			else:
				raise web.seeother('/404')
		except Exception as e:
			print "WEBSERVICE Error {}".format(e.args)
			raise web.seeother('/404')



#Author : Salvador Hernandez Mendoza
#Email  : salvadorhm@gmail.com
#Twitter: @salvadorhm
import web
import application
import hashlib
import config

ssl = True #activate ssl certificate 

urls = (
    '/', 'application.controllers.main.index.Index',
    '/login', 'application.controllers.main.login.Login',
    '/logout', 'application.controllers.main.logout.Logout',
    '/guess', 'application.controllers.main.guess.Guess',
)

app = web.application(urls, globals())

if ssl == True:
    from web.wsgiserver import CherryPyWSGIServer
    CherryPyWSGIServer.ssl_certificate = "ssl/server.crt" 
    CherryPyWSGIServer.ssl_private_key = "ssl/server.key"

store = web.session.DiskStore('sessions')

if web.config.get('_session') is None:
    db = config.db
    store = web.session.DBStore(db, 'sessions')
    session = web.session.Session(
        app,
        store,
        initializer={
        'login': 0,
        'privilege': 0,
        'user':'anonymous',
        'loggedin':False,
        'count' : 0
        }
        )
    web.config._session = session
    web.config.session_parameters['cookie_name'] = 'kuorra'
    web.config.session_parameters['timeout'] = 10
    web.config.session_parameters['expired_message'] = 'Session expired'
    web.config.session_parameters['ignore_expiry'] = False
    web.config.session_parameters['ignore_change_ip'] = False
    web.config.session_parameters['secret_key'] = 'fLjUfxqXtfNoIldA0A0J'
else:
    session = web.config._session

class count:
    def GET(self):
        session.count += 1
        return str(session.count)

def internalerror():
    raise config.web.seeother('/')

def notfound():
    raise config.web.seeother('/')

if __name__ == "__main__":
    web.config.debug = False
    web.config.db_printing = False
    app.internalerror = internalerror
    app.notfound = notfound
    app.run()



import web
import application.models.model_users

render = web.template.render('application/views/main/', base='master')
model = application.models.model_users

form = web.form.Form(
        web.form.Textbox(
            'username', 
            web.form.notnull, 
            size=30, 
            description="Username:", 
            class_="form-control"
            ),
        web.form.Password(
            'password', 
            web.form.notnull, 
            size=30, 
            description="Password:", 
            class_="form-control"
            ),
        web.form.Button(
            'Login', 
            class_="form-control"
            )
    )


import web

db_host = 'localhost'
db_name = 'acme_store_mvc'
db_user = 'root'
db_pw = 'toor'

db = web.database(
    dbn='mysql',
    host=db_host,
    db=db_name,
    user=db_user,
    pw=db_pw
    )


import config
import app
import hashlib

class Login:

    def GET(self):
        form = config.form()
        return config.render.login(form)
        
    
    def POST(self):
        i= config.web.input()
        pwdhash = hashlib.md5(i.password).hexdigest()
        check = config.model.validate_user(i.username, pwdhash)
        username = check['username']
        privilege = check['privilege']
        if check: 
            app.session.loggedin = True
            app.session.username = username
            app.session.privilege = privilege
            raise config.web.seeother('/')   
        else: 
            form = config.form()
            return config.render.login(form)


import config
import app

class Index:

    def GET(self):  
        if app.session.loggedin == True:
            username = app.session.username
            privilege = app.session.privilege
            if  privilege == 1:
                raise config.web.seeother('/guess')
            elif privilege == 0:
                return config.render.index(username)
        else:
            raise config.web.seeother('/login')



import config

class Delete:

    def GET(self, id_person):
        persons = config.form_persons()
        result = config.model.get_persons(id_person)
        persons.fill(result)
        return config.render.delete(persons)

    def POST(self, id_person):
        config.model.delete_persons(id_person)
        raise config.web.seeother('/')



import shutil, errno
import sys
from subprocess import call
import os
from model_generator import Model_generator as model_generator
from api_generator import Api_generator as api_generator


version = '0.4.0'

def new_base(args):
	name = args[2]
	print 'Creating new project ....'
	print 'Project: {}'.format(name)
	script_path = os.path.abspath(__file__)
	script_dir = os.path.split(script_path)[0]
	rel_path = "mvc_base"
	abs_file_path = os.path.join(script_dir, rel_path)
	#call(['ls -l'], shell = True)
	copyanything(abs_file_path, name)
	print 'Project created succesful'

def new_login(args):
	name = args[2]
	print 'Creating new login project ....'
	print 'Project: {}'.format(name)
	script_path = os.path.abspath(__file__)
	script_dir = os.path.split(script_path)[0]
	rel_path = "mvc_sessions"
	abs_file_path = os.path.join(script_dir, rel_path)
	#call(['ls -l'], shell = True)
	copyanything(abs_file_path, name)
	print 'Project created succesful'

def new_forms(args):
	name = args[2]
	print 'Creating new project ....'
	print 'Project: {}'.format(name)
	script_path = os.path.abspath(__file__)
	script_dir = os.path.split(script_path)[0]
	rel_path = "mvc_forms"
	abs_file_path = os.path.join(script_dir, rel_path)
	#call(['ls -l'], shell = True)
	copyanything(abs_file_path, name)
	print 'Project created succesful'
def copyanything(src, dst):
	try:
		shutil.copytree(src, dst)
	except OSError as exc:
		if exc.errno == errno.ENOTDIR:
			shutil.copy(src, dst)
		else: raise

def new(args):
	name = args[2]
	print 'Creating new project ....'
	print 'Project: {}'.format(name)
	script_path = os.path.abspath(__file__)
	script_dir = os.path.split(script_path)[0]
	rel_path = "mvc"
	abs_file_path = os.path.join(script_dir, rel_path)
	#call(['ls -l'], shell = True)
	copyanything(abs_file_path, name)
	print 'Project created succesful'

def info():
	print 'kuorra V {}'.format(version)
	print 'Author	: Salvador Hernandez Mendoza'
	print 'Email 	: salvadorhm@gmail.com'
	print 'Twiter 	: @salvadorhm'

def help():
	print 'kuorra V {}'.format(version)
	print ''
	print 'HELP'
	print ''
	print 'project_name \t- Project name'
	print 'host \t- Database host'
	print 'db \t- Database name'
	print 'user \t- Database user'
	print 'pw \t- Database password'
	print 'table \t- Database table name'
	print ''
	print 'COMMANDS'
	print ''
	print 'kuorra -n project_name -> NEW PROJECT'
	print 'kuorra -nb project_name -> NEW BLANK PROJECT'
	print 'kuorra -nf project_name -> NEW WEB.PY FORMS USE'
	print 'kuorra -nl project_name -> NEW WEB.PY LOGIN PROJECT'
	print 'kuorra -d -> DEPLOY PROJECT'
	print 'kuorra -i -> INFORMATION'
	print 'kuorra -am db host user pw -> CREATE ALL TABLES MODELS'
	print 'kuorra -m db table host user pw -> CREATE ONE TABLE MODEL'
	print 'kuorra -aa db host user pw -> CREATE ALL TABLES API'
	print 'kuorra -a db table host user pw -> CREATE ONE TABLE API'
	print ''
	

def deploy():
	try:
		call(['clear'], shell = False)
		print '*******************************************************'
		print '*kuorra V {}'.format(version)
		print '*  kuorra WebApp Deploy'
		print '*  For OPEN use Crtl + click in URL'
		print '*  For STOP use Crtl + C  '
		print '*******************************************************'
		print '*************    kuorra Console       *****************'
		print '*******************************************************\n'
		call(['python app.py'], shell = True)
	except (KeyboardInterrupt, SystemExit):
		print 'kuorra shutdown..'

def all_models(args):
	name = args[2]
	db_host = args[3]
	db_name = name
	db_user = args[4]
	db_pw = args[5]

	model = model_generator()

	model.db_host = db_host
	model.db_name = db_name
	model.db_user = db_user
	model.db_pw = db_pw

	'''
	print 'host: '+model_generator.db_host
	print 'db_name: '+model_generator.db_name
	print 'db_user: '+model_generator.db_user
	print 'db_pw: '+model_generator.db_pw
	'''

	model.table_name = name

	model.conectar()
	model.generate()

def one_model(args):
	name = args[2]
	db_table = args[3]
	db_host = args[4]
	db_name = name
	db_user = args[5]
	db_pw = args[6]

	model = model_generator()


	model.db_host = db_host
	model.db_name = db_name
	model.db_user = db_user
	model.db_pw = db_pw
	model.table_name = db_table

	'''
	print 'host: '+model_generator.db_host
	print 'table_name: '+ db_table
	print 'db_name: '+model_generator.db_name
	print 'db_user: '+model_generator.db_user
	print 'db_pw: '+model_generator.db_pw
	'''

	model.conectar()
	model.generate_one(db_table)

def all_apis(args):
	name = args[2]
	db_host = args[3]
	db_name = name
	db_user = args[4]
	db_pw = args[5]

	api = api_generator()

	api.db_host = db_host
	api.db_name = db_name
	api.db_user = db_user
	api.db_pw = db_pw

	'''
	print 'host: '+model_generator.db_host
	print 'db_name: '+model_generator.db_name
	print 'db_user: '+model_generator.db_user
	print 'db_pw: '+model_generator.db_pw
	'''

	api.table_name = name

	api.conectar()
	api.generate()

def one_api(args):
	name = args[2]
	db_table = args[3]
	db_host = args[4]
	db_name = name
	db_user = args[5]
	db_pw = args[6]

	api = api_generator()


	api.db_host = db_host
	api.db_name = db_name
	api.db_user = db_user
	api.db_pw = db_pw
	api.table_name = db_table

	'''
	print 'host: '+api_generator.db_host
	print 'table_name: '+ db_table
	print 'db_name: '+api_generator.db_name
	print 'db_user: '+api_generator.db_user
	print 'db_pw: '+api_generator.db_pw
	'''
	
	api.conectar()
	api.generate_one(db_table)

def main():
	try:
		command = sys.argv[1]
		if command == 'new' or command == '-n':
			new(sys.argv)
		elif command == 'new_base' or command == '-nb':
			new_base(sys.argv)
		elif command == 'new_forms' or command == '-nf':
			new_forms(sys.argv)
		elif command == 'new_login' or command == '-nl':
			new_login(sys.argv)
		elif command == 'info' or command == '-i':
			info()
		elif command == 'dep' or command == '-d':
			deploy()
		elif command == 'help' or command == '-h':
			help()
		elif command == 'all_models' or command == '-am':
			all_models(sys.argv)
		elif command == 'model' or command == '-m':
			one_model(sys.argv)
		elif command == 'all_apis' or command == '-aa':
			all_apis(sys.argv)
		elif command == 'api' or command == '-a':
			one_api(sys.argv)
		else:
			help()
	except Exception as e:
		print 'Error, use -h for help'
		print e.message

if __name__ == "__main__":
	main()


import config

class Edit:
	
	def GET(self, id_product):
		result = config.model.get_products(int(id_product))
		return config.render.edit(result)

	def POST(self, id_product):
		form = config.web.input()
		image = config.web.input(product_image={})
		filedir = 'static/files'
		filepath = image.product_image.filename.replace('\\', '/')
		filename = filepath.split('/')[-1]
		fout = open(filedir + '/' + filename, 'w')
		fout.write(image.product_image.file.read())
		fout.close()
		product_image = filename

		config.model.edit_products(
			form['id_product'],
			form['product'],
			form['description'],
			form['stock'],
			form['purchase_price'],
			form['price_sale'],
			product_image
		)
		raise config.web.seeother('/')


from setuptools import setup, find_packages  # Always prefer setuptools over distutils

long_description = """
Create basic MVC skeleton using Web.py Microframework and Heroku ready:
Functions:
    bootstrap - frontend framework
    jquery - js framework
    scheme.sql - MySQL demo database
    api - Restfull API
    ssl - HTTPS conection
    requirements.txt - Heroku requirements
    Procfile - Heroku config
"""

setup(
    name="kuorra",
    version="0.4.0",
    description="Create basic MVC skeleton using Web.py Microframework",

    long_description=long_description,
    
    author="Salvador Hernandez Mendoza",
    
    author_email="salvadorhm@gmail.com",
    
    license="GPLv3",
    
    url="https://salvadorhm.github.io/kuorra",
    
    download_url="https://salvadorhm.github.io/kuorra",
    
    classifiers=['Development Status :: 4 - Beta',
                'Intended Audience :: Developers',
                'Topic :: Software Development',
                'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
                'Programming Language :: Python :: 2.7'],
    keywords="mvc web.py mysql heroku bootstrap jquery ssl api restful",
    install_requires=["web.py==0.38", "MySQL-python==1.2.5", "pyOpenSSL==16.2.0"],
    zip_safe=False,

    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*",
                                    "tests", "*tests*"]),
    entry_points={'console_scripts': ['kuorra=kuorra.kuorra:main'],
                },
    package_data={"kuorra": [
            "__init__.py",
            "__main__.py",
            "kuorra.py",
            "model_generator.py",
            "api_generator.py",
            "plugin/model_master.py",
            "plugin/api_master_cool.py",
            "mvc/__init__.py",
            "mvc/app.py",
            "mvc/Procfile",
            "mvc/requirements.txt",
            "mvc/Readme.md",
            "mvc/ssl",
            "mvc/ssl/server.crt",
            "mvc/ssl/server.csr",
            "mvc/ssl/server.key",
            "mvc/application/__init__.py",
            "mvc/application/controllers/__init__.py",
            "mvc/application/controllers/products/config.py",
            "mvc/application/controllers/products/delete.py",
            "mvc/application/controllers/products/edit.py",
            "mvc/application/controllers/products/index.py",
            "mvc/application/controllers/products/__init__.py",
            "mvc/application/controllers/products/insert.py",
            "mvc/application/controllers/products/view.py",
            "mvc/application/models/config.py",
            "mvc/application/models/__init__.py",
            "mvc/application/models/model_products.py",
            "mvc/application/views/__init__.py",
            "mvc/application/views/products/delete.html",
            "mvc/application/views/products/edit.html",
            "mvc/application/views/products/index.html",
            "mvc/application/views/products/__init__.py",
            "mvc/application/views/products/insert.html",
            "mvc/application/views/products/master.html",
            "mvc/application/views/products/view.html",
            "mvc/application/api/__init__.py",
            "mvc/application/api/products/__init__.py",
            "mvc/application/api/products/api_products.py",
            "mvc/application/api/products/config.py",
            "mvc/data/schema.sql",
            "mvc/static/css/bootstrap.css",
            "mvc/static/css/index.html",
            "mvc/static/files/default.jpg",
            "mvc/static/fonts/glyphicons-halflings-regular.eot",
            "mvc/static/fonts/glyphicons-halflings-regular.svg",
            "mvc/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc/static/fonts/glyphicons-halflings-regular.woff",
            "mvc/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc/static/fonts/index.html",
            "mvc/static/js/bootstrap.js",
            "mvc/static/js/index.html",
            "mvc/static/js/jquery.js",
            "mvc_forms/__init__.py",
            "mvc_forms/app.py",
            "mvc_forms/Procfile",
            "mvc_forms/requirements.txt",
            "mvc_forms/Readme.md",
            "mvc_forms/ssl",
            "mvc_forms/ssl/server.crt",
            "mvc_forms/ssl/server.csr",
            "mvc_forms/ssl/server.key",
            "mvc_forms/application/__init__.py",
            "mvc_forms/application/controllers/__init__.py",
            "mvc_forms/application/controllers/persons/config.py",
            "mvc_forms/application/controllers/persons/delete.py",
            "mvc_forms/application/controllers/persons/update.py",
            "mvc_forms/application/controllers/persons/index.py",
            "mvc_forms/application/controllers/persons/__init__.py",
            "mvc_forms/application/controllers/persons/insert.py",
            "mvc_forms/application/controllers/persons/view.py",
            "mvc_forms/application/models/config.py",
            "mvc_forms/application/models/__init__.py",
            "mvc_forms/application/models/model_persons.py",
            "mvc_forms/application/views/__init__.py",
            "mvc_forms/application/views/persons/delete.html",
            "mvc_forms/application/views/persons/update.html",
            "mvc_forms/application/views/persons/index.html",
            "mvc_forms/application/views/persons/__init__.py",
            "mvc_forms/application/views/persons/insert.html",
            "mvc_forms/application/views/persons/master.html",
            "mvc_forms/application/views/persons/view.html",
            "mvc_forms/application/api/__init__.py",
            "mvc_forms/application/api/persons/__init__.py",
            "mvc_forms/application/api/persons/api_persons.py",
            "mvc_forms/application/api/persons/config.py",
            "mvc_forms/data/schema.sql",
            "mvc_forms/static/css/bootstrap.css",
            "mvc_forms/static/css/index.html",
            "mvc_forms/static/files/default.jpg",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.eot",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.svg",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.woff",
            "mvc_forms/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc_forms/static/fonts/index.html",
            "mvc_forms/static/js/bootstrap.js",
            "mvc_forms/static/js/index.html",
            "mvc_forms/static/js/jquery.js",
            "mvc_base/__init__.py",
            "mvc_base/app.py",
            "mvc_base/Procfile",
            "mvc_base/requirements.txt",
            "mvc_base/Readme.md",
            "mvc_base/ssl",
            "mvc_base/ssl/server.crt",
            "mvc_base/ssl/server.csr",
            "mvc_base/ssl/server.key",
            "mvc_base/application/__init__.py",
            "mvc_base/application/controllers/__init__.py",
            "mvc_base/application/controllers/main/config.py",
            "mvc_base/application/controllers/main/index.py",
            "mvc_base/application/controllers/main/__init__.py",
            "mvc_base/application/models/config.py",
            "mvc_base/application/models/__init__.py",
            "mvc_base/application/views/__init__.py",
            "mvc_base/application/views/main/index.html",
            "mvc_base/application/views/main/master.html",
            "mvc_base/application/views/main/__init__.py",
            "mvc_base/application/api/__init__.py",
            "mvc_base/data/schema.sql",
            "mvc_base/static/css/bootstrap.css",
            "mvc_base/static/css/index.html",
            "mvc_base/static/files/default.jpg",
            "mvc_base/static/fonts/glyphicons-halflings-regular.eot",
            "mvc_base/static/fonts/glyphicons-halflings-regular.svg",
            "mvc_base/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc_base/static/fonts/glyphicons-halflings-regular.woff",
            "mvc_base/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc_base/static/fonts/index.html",
            "mvc_base/static/js/bootstrap.js",
            "mvc_base/static/js/index.html",
            "mvc_base/static/js/jquery.js",
            "mvc_sessions/__init__.py",
            "mvc_sessions/app.py",
            "mvc_sessions/Procfile",
            "mvc_sessions/requirements.txt",
            "mvc_sessions/Readme.md",
            "mvc_sessions/config.py",
            "mvc_sessions/ssl",
            "mvc_sessions/ssl/server.crt",
            "mvc_sessions/ssl/server.csr",
            "mvc_sessions/ssl/server.key",
            "mvc_sessions/application/__init__.py",
            "mvc_sessions/application/controllers/__init__.py",
            "mvc_sessions/application/controllers/main/config.py",
            "mvc_sessions/application/controllers/main/guess.py",
            "mvc_sessions/application/controllers/main/index.py",
            "mvc_sessions/application/controllers/main/login.py",
            "mvc_sessions/application/controllers/main/logout.py",
            "mvc_sessions/application/controllers/main/__init__.py",
            "mvc_sessions/application/models/config.py",
            "mvc_sessions/application/models/model_users.py",
            "mvc_sessions/application/models/__init__.py",
            "mvc_sessions/application/views/__init__.py",
            "mvc_sessions/application/views/main/guess.html",
            "mvc_sessions/application/views/main/index.html",
            "mvc_sessions/application/views/main/login.html",
            "mvc_sessions/application/views/main/master.html",
            "mvc_sessions/application/views/main/__init__.py",
            "mvc_sessions/application/api/__init__.py",
            "mvc_sessions/data/schema.sql",
            "mvc_sessions/static/css/bootstrap.css",
            "mvc_sessions/static/css/index.html",
            "mvc_sessions/static/files/default.jpg",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.eot",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.svg",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.ttf",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.woff",
            "mvc_sessions/static/fonts/glyphicons-halflings-regular.woff2",
            "mvc_sessions/static/fonts/index.html",
            "mvc_sessions/static/js/bootstrap.js",
            "mvc_sessions/static/js/index.html",
            "mvc_sessions/static/js/jquery.js"
            ]}
)


#Author : Salvador Hernandez Mendoza
#Email  : salvadorhm@gmail.com
#Twitter: @salvadorhm
import web
import application

ssl = True #activate ssl certificate 

if ssl == True:
    from web.wsgiserver import CherryPyWSGIServer
    '''
    Use OpenSSL to generate  keys

    user@host$ openssl genrsa -out server.key 1024
    user@host$ openssl req -new -key server.key -out server.csr
    user@host$ openssl x509 -req -days 365 -in server.csr -signkey server.key -out server.crt

    '''
    CherryPyWSGIServer.ssl_certificate = "ssl/server.crt" 
    CherryPyWSGIServer.ssl_private_key = "ssl/server.key"

urls = (
    '/', 'application.controllers.products.index.Index',
    '/products/view/(.+)', 'application.controllers.products.view.View',
    '/products/insert', 'application.controllers.products.insert.Insert',
    '/products/edit/(.+)', 'application.controllers.products.edit.Edit',
    '/products/delete/(.+)', 'application.controllers.products.delete.Delete',
    '/api_products/?', 'application.api.products.api_products.Api_products',
)

if __name__ == "__main__":
    app = web.application(urls, globals())
    web.config.debug = False
    app.run()



import config

class Update:

    def GET(self, id_person):
        persons = config.form_persons()
        result = config.model.get_persons(id_person)
        persons.fill(result)
        return config.render.update(persons)

    def POST(self, id_person):
        persons = config.form_persons()
        if persons.validates():
            config.model.update_persons(**persons.d)
            raise config.web.seeother('/')
        else:
            return config.render.update(persons)



import config

class Insert:

    def GET(self):
        persons = config.form_persons()
        return config.render.insert(persons)

    def POST(self):
        persons = config.form_persons()
        if persons.validates():
            config.model.insert_persons(**persons.d)
            raise config.web.seeother('/')
        else:
            return config.render.insert(persons)



import web
import config

db = config.db

def get_all_persons():
    try:
        return db.select('persons')
    except Exception as e:
        print "Model get all Error {}".format(e.args)
        print "Model get all Message {}".format(e.message)
        return None

def get_persons(id_person):
    try:
        return db.select('persons', where='id_person=$id_person', vars=locals())[0]
    except Exception as e:
        print "Model get Error {}".format(e.args)
        print "Model get Message {}".format(e.message)
        return None

def delete_persons(id_person):
    try:
        return db.delete('persons', where='id_person=$id_person', vars=locals())
    except Exception as e:
        print "Model delete Error {}".format(e.args)
        print "Model delete Message {}".format(e.message)
        return None

def insert_persons(id_person,name,telephone,email):
    try:
        db.insert('persons',id_person=id_person,
name=name,
telephone=telephone,
email=email)
    except Exception as e:
        print "Model insert Error {}".format(e.args)
        print "Model insert Message {}".format(e.message)
        return None

def update_persons(id_person,name,telephone,email):
    try:
        db.update('persons',id_person=id_person,
name=name,
telephone=telephone,
email=email,
                  where='id_person=$id_person',
                  vars=locals())
    except Exception as e:
        print "Model update Error {}".format(e.args)
        print "Model updateMessage {}".format(e.message)
        return None
